coinor.blimpy.Stack'

Package coinor :: Package blimpy :: Module Stack' |
[hide private]
[frames] | no frames]

# Module Stack'

source code

A basic stack implementation using a linked list.

Version: 1.1.0

Author: Aykut Bulut, Ted Ralphs (ayb211@lehigh.edu,ted@lehigh.edu)

License: BSD

Classes | [hide private]
| Stack This stack class is built on top of a linked list data structure.

Variables | [hide private]
| __email__ = ``'``ayb211@lehigh.edu``'``
| __maintainer__ = ``'``Aykut Bulut``'``
| __package__ = ``'``coinor.blimpy``'``
| __title__ = ``'``Stack data structure``'``
| __url__ = `None`